@@ -151,7 +151,7 @@ void View::twitOk()
 	 
 	 std::string status = std::string("I just scored ");
 	status.append(QString::number(1000-game->score).toStdString());
-	status.append(" points in #Sheep");
+	status.append(" points in #MaeSheep in #maemo");
 	 
 
   
@@ -198,6 +198,13 @@ void View::mousePressEvent(QMouseEvent* event)
 		if (game->pauseOn)
 			return;
 		
+	//	if (pois[0]->boundingRect().contains(-pois[0]->x+event->globalX()+40,-pois[0]->y+event->globalY()+40))
+		qreal d = sqrt(pow(pois[0]->x-event->globalX(),2)+pow(pois[0]->y-event->globalY(),2));
+		
+		if (d<50)
+		{
+			return;
+		}
 		poi=new Poi(event->globalX(),event->globalY(),86,40,1);
 		poi->setPos(event->globalX(),event->globalY());
 		connect(poi,SIGNAL(deleteMe(Poi*)),this,SLOT(removeItem(Poi*)));
@@ -232,7 +239,7 @@ void View::removeItem(Poi* poi)
 	{
 		if (pois[i]==poi && poi!=NULL)
 		{
-			delete poi;
+			//delete poi;
 			pois.erase(pois.begin()+i);
 			return;
 		}
